@@ -14,6 +14,7 @@
 
 import os
 import re
+import logging
 from typing import List, Dict, Any, Optional, Union
 from .value_parser import parse_value, parse_nodeid
 from .ua_data_types import UANodeId
@@ -23,12 +24,16 @@ import pandas as pd
 import logging
 from io import BytesIO
 
+
 logger = logging.getLogger(__name__)
 cl = logging.StreamHandler()
 logger.setLevel(logging.INFO)
-formatter = logging.Formatter("%(asctime)s - %(name)s - %(levelname)s - %(message)s")
+formatter = logging.Formatter(
+    "%(asctime)s - %(levelname)s - %(name)s.%(funcName)s().%(lineno)d: %(message)s"
+)
 cl.setFormatter(formatter)
 logger.addHandler(cl)
+pd.set_option("display.max_rows", None, "display.max_columns", None)
 
 tagsplit = re.compile(r"({.*\})(.*)")
 
@@ -231,12 +236,7 @@ def iterparse_xml(
         elif event == "end":
             elems.append(elem)
         if i % batchsize == 0:
-            logger.info(
-                "Processing "
-                + str(int(batchsize / 2))
-                + " nodes from "
-                + str(int(i * batchsize / 2))
-            )
+            logger.info(f"Processing XML node batch {i}")
             df = process_elem_batch(
                 elems=elems,
                 uaxsd=uaxsd,
